@@ -27,10 +27,10 @@ tkwm.title(tt, "Self-test, the normal pdf")
 tkgrid(tklabel(tt,text=""))
 tkgrid(tklabel(tt, text = "What does the normal pdf describe?"), columnspan = 2)
 tkgrid(tklabel(tt,text=""))
-tkgrid(tklabel(tt,text="  a.    A continuous response, e.g. height or weight.  "),rb1, sticky = "w")
+tkgrid(tklabel(tt,text="  a.    A continuous random variable, e.g. height or weight.  "),rb1, sticky = "w")
 tkgrid(tklabel(tt,text="  b.    The number of successes, with a lower limit of 0, and an unbounded upper limit.  "),rb2, sticky = "w")
 tkgrid(tklabel(tt,text="  c.    The number of successes, with a lower limit of 0, and an upper bound of n.  "),rb3, sticky ="w")
-tkgrid(tklabel(tt,text="  d.    A discrete response, e.g. height or weight.   "),rb4,sticky="w")
+tkgrid(tklabel(tt,text="  d.    A discrete random variable, e.g. height or weight.   "),rb4,sticky="w")
 tkgrid(tklabel(tt,text=""))
 OnOK <- function()
 {
@@ -82,22 +82,22 @@ tkwm.title(tt, "Self-test, the binomial pdf")
 tkgrid(tklabel(tt,text=""))
 tkgrid(tklabel(tt, text = "What does the binomial pdf describe?"), columnspan = 2)
 tkgrid(tklabel(tt,text=""))
-tkgrid(tklabel(tt,text="  a.    A continuous response, e.g. height or weight.  "),rb1, sticky = "w")
+tkgrid(tklabel(tt,text="  a.    A continuous random variable, e.g. height or weight.  "),rb1, sticky = "w")
 tkgrid(tklabel(tt,text="  b.    The number of successes, with a lower limit of 0, and an unbounded upper limit.  "),rb2, sticky = "w")
 tkgrid(tklabel(tt,text="  c.    The number of successes, with a lower limit of 0, and an upper bound of n.  "),rb3, sticky ="w")
-tkgrid(tklabel(tt,text="  d.    A discrete response, e.g. height or weight.   "),rb4,sticky="w")
+tkgrid(tklabel(tt,text="  d.    A discrete random variable, e.g. height or weight.   "),rb4,sticky="w")
 tkgrid(tklabel(tt,text=""))
 OnOK <- function()
 {
     rbVal <- as.character(tclvalue(rbValue))
     if (rbVal=="a")
-    	tkmessageBox(message="Incorrect.  The binomial pdf discribes discrete random variables.",icon="error")
+    	tkmessageBox(message="Incorrect.  The binomial pdf describes discrete random variables.",icon="error")
     if (rbVal=="b")
     	tkmessageBox(message="Incorrect.  The upper bound will equal the number of trials, n",icon="error")
     if (rbVal=="c")
     	tkmessageBox(message="Correct.")
     if (rbVal=="d")
-    	tkmessageBox(message="Incorrect.  The binomial pdf discribes describes discrete random variables (height and weight are not discrete).",icon="error")  	
+    	tkmessageBox(message="Incorrect.  The binomial pdf describes discrete random variables (height and weight are not discrete).",icon="error")  	
 }
 
 OK.but <- tkbutton(tt,text="OK",command=OnOK)
